# -*- coding: utf-8 -*-
"""한국어 언어 리소스 (Korean language resources)"""

translations = {
    "palaces": {
        "soulPalace": "명궁",
        "parentsPalace": "부모궁",
        "spiritPalace": "복덕궁",
        "propertyPalace": "전택궁",
        "careerPalace": "관록궁",
        "friendsPalace": "교우궁",
        "surfacePalace": "천이궁",
        "healthPalace": "질액궁",
        "wealthPalace": "재백궁",
        "childrenPalace": "자녀궁",
        "spousePalace": "부처궁",
        "siblingsPalace": "형제궁",
    },
    "stars": {
        "major": {
            "ziweiMaj": "자미",
            "tianjiMaj": "천기",
            "taiyangMaj": "태양",
            "wuquMaj": "무곡",
            "tiantongMaj": "천동",
            "lianzhenMaj": "염정",
            "tianfuMaj": "천부",
            "taiyinMaj": "태음",
            "tanlangMaj": "탐랑",
            "jumenMaj": "거문",
            "tianxiangMaj": "천상",
            "tianliangMaj": "천량",
            "qishaMaj": "칠살",
            "pojunMaj": "파군",
        },
        "minor": {
            "zuofuMin": "좌보",
            "youbiMin": "우필",
            "wenchangMin": "문창",
            "wenquMin": "문곡",
            "tiankuiMin": "천괴",
            "tianyueMin": "천월",
            "huoxingMin": "화성",
            "lingxingMin": "영성",
            "dikongMin": "지공",
            "dijieMin": "지겁",
            "lucunMin": "녹존",
            "qingyangMin": "경양",
            "tuoluoMin": "타라",
            "tianmaMin": "천마",
        },
    },
    "heavenlyStem": {
        "jiaHeavenly": "갑",
        "yiHeavenly": "을",
        "bingHeavenly": "병",
        "dingHeavenly": "정",
        "wuHeavenly": "무",
        "jiHeavenly": "기",
        "gengHeavenly": "경",
        "xinHeavenly": "신",
        "renHeavenly": "임",
        "guiHeavenly": "계",
    },
    "earthlyBranch": {
        "ziEarthly": "자",
        "chouEarthly": "축",
        "yinEarthly": "인",
        "maoEarthly": "묘",
        "chenEarthly": "진",
        "siEarthly": "사",
        "wuEarthly": "오",
        "weiEarthly": "미",
        "shenEarthly": "신",
        "youEarthly": "유",
        "xuEarthly": "술",
        "haiEarthly": "해",
    },
    "brightness": {
        "miao": "묘",
        "wang": "왕",
        "de": "득",
        "li": "리",
        "ping": "평",
        "bu": "불",
        "xian": "함",
    },
}
