# -*- coding: utf-8 -*-
"""Tài nguyên ngôn ngữ tiếng Việt (Vietnamese language resources)"""

translations = {
    "palaces": {
        "soulPalace": "Mệnh Cung",
        "parentsPalace": "Phụ Mẫu Cung",
        "spiritPalace": "Phúc Đức Cung",
        "propertyPalace": "Điền Trạch Cung",
        "careerPalace": "Quan Lộc Cung",
        "friendsPalace": "Giao Hữu Cung",
        "surfacePalace": "Thiên Di Cung",
        "healthPalace": "Tật Ách Cung",
        "wealthPalace": "Tài Bạch Cung",
        "childrenPalace": "Tử Nữ Cung",
        "spousePalace": "Phu Thê Cung",
        "siblingsPalace": "Huynh Đệ Cung",
    },
    "stars": {
        "major": {
            "ziweiMaj": "Tử Vi",
            "tianjiMaj": "Thiên Cơ",
            "taiyangMaj": "Thái Dương",
            "wuquMaj": "Vũ Khúc",
            "tiantongMaj": "Thiên Đồng",
            "lianzhenMaj": "Liêm Trinh",
            "tianfuMaj": "Thiên Phủ",
            "taiyinMaj": "Thái Âm",
            "tanlangMaj": "Tham Lang",
            "jumenMaj": "Cự Môn",
            "tianxiangMaj": "Thiên Tướng",
            "tianliangMaj": "Thiên Lương",
            "qishaMaj": "Thất Sát",
            "pojunMaj": "Phá Quân",
        },
        "minor": {
            "zuofuMin": "Tả Phụ",
            "youbiMin": "Hữu Bật",
            "wenchangMin": "Văn Xương",
            "wenquMin": "Văn Khúc",
            "tiankuiMin": "Thiên Khôi",
            "tianyueMin": "Thiên Việt",
            "huoxingMin": "Hỏa Tinh",
            "lingxingMin": "Linh Tinh",
            "dikongMin": "Địa Không",
            "dijieMin": "Địa Kiếp",
            "lucunMin": "Lộc Tồn",
            "qingyangMin": "Kình Dương",
            "tuoluoMin": "Đà La",
            "tianmaMin": "Thiên Mã",
        },
    },
    "heavenlyStem": {
        "jiaHeavenly": "Giáp",
        "yiHeavenly": "Ất",
        "bingHeavenly": "Bính",
        "dingHeavenly": "Đinh",
        "wuHeavenly": "Mậu",
        "jiHeavenly": "Kỷ",
        "gengHeavenly": "Canh",
        "xinHeavenly": "Tân",
        "renHeavenly": "Nhâm",
        "guiHeavenly": "Quý",
    },
    "earthlyBranch": {
        "ziEarthly": "Tý",
        "chouEarthly": "Sửu",
        "yinEarthly": "Dần",
        "maoEarthly": "Mão",
        "chenEarthly": "Thìn",
        "siEarthly": "Tỵ",
        "wuEarthly": "Ngọ",
        "weiEarthly": "Mùi",
        "shenEarthly": "Thân",
        "youEarthly": "Dậu",
        "xuEarthly": "Tuất",
        "haiEarthly": "Hợi",
    },
    "brightness": {
        "miao": "Miếu",
        "wang": "Vượng",
        "de": "Đắc",
        "li": "Lợi",
        "ping": "Bình",
        "bu": "Bất",
        "xian": "Hãm",
    },
}
