"""
Language resource files for internationalization.

Available locales:
- zh_CN: Simplified Chinese (简体中文)
- zh_TW: Traditional Chinese (繁體中文)
- en_US: English
- ja_JP: Japanese (日本語)
- ko_KR: Korean (한국어)
- vi_VN: Vietnamese (Tiếng Việt)
"""

__all__ = ['zh_CN', 'zh_TW', 'en_US', 'ja_JP', 'ko_KR', 'vi_VN']
